==> ifrit_3.2.5.orig.tar.gz: ifrit-3.2.5/shells/generic/iggframedatatypeselector.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A frame with a ComboBox listing available DataTypes
//

#ifndef IGGFRAMEDATATYPESELECTOR_H
#define IGGFRAMEDATATYPESELECTOR_H


#include "iggframe.h"


#include "iggparameter.h"

class iDataInfo;
class iObjectKey;

class iggDataTypeProvider;


class iggFrameDataTypeSelector : public iggFrame
{

public:

	iggFrameDataTypeSelector(iggDataTypeProvider *provider, bool withapply, const iString &title, iggFrameBase *parent, int mode = iggParameter::_ListDataTypesAll);
	virtual ~iggFrameDataTypeSelector();

	inline int GetMode() const { return mMode; }
	void SetMode(int m);

	const iDataInfo* GetDataInfo();

	bool IsModified() const;
	void SetCurrentDataTypeIndex(int v);
	inline int GetCurrentDataTypeIndex() const { return mCurrentDataTypeIndex; }

	void Apply();

protected:

	void UpdateProvider();
	virtual void UpdateWidgetBody();

	iDataInfo *mInfoPointer;
	bool mAutoApplying;
	int mMode, mCurrentDataTypeIndex;
	iggDataTypeProvider *mProvider;
	iggFrame *mBase;
};

#endif  // IGGFRAMEDATACHANNEL_H

==> ifrit_3.3.2.orig.tar.gz: ifrit-3.3.2/shells/generic/iggframedatatypeselector.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A frame with a ComboBox listing available DataTypes
//

#ifndef IGGFRAMEDATATYPESELECTOR_H
#define IGGFRAMEDATATYPESELECTOR_H


#include "iggframe.h"


class iDataInfo;
class iObjectKey;

class iggDataTypeProvider;


namespace iParameter
{
	//
	//  DataTypeSelector modes
	//
	namespace ListDataTypes
	{
		const int All =				0;
		const int WithData =		1;
		const int WithVariables =	2;
	};
};


class iggFrameDataTypeSelector : public iggFrame
{

public:

	iggFrameDataTypeSelector(iggDataTypeProvider *provider, bool withapply, const iString &title, iggFrameBase *parent, int mode = iParameter::ListDataTypes::All);
	virtual ~iggFrameDataTypeSelector();

	inline int GetMode() const { return mMode; }
	void SetMode(int m);

	const iDataInfo* GetDataInfo();

	bool IsModified() const;
	void SetCurrentDataTypeIndex(int v);
	inline int GetCurrentDataTypeIndex() const { return mCurrentDataTypeIndex; }

	void Apply();

protected:

	void UpdateProvider();
	virtual void UpdateWidgetBody();

	iDataInfo *mInfoPointer;
	bool mAutoApplying;
	int mMode, mCurrentDataTypeIndex;
	iggDataTypeProvider *mProvider;
	iggFrame *mBase;
};

#endif  // IGGFRAMEDATACHANNEL_H
